--------------------------------------------------------------------
-- Support functions
--------------------------------------------------------------------


---------------------------
-- format memory usage
---------------------------
function Glance.Functions.FormatMemory(usage)
	if usage > 1000 then
		return format("%.2f mb", usage/1024)
	elseif usage > 0 then
		return format("%.2f kb", usage)
	end
end

---------------------------
-- durability % function
---------------------------
function Glance.Functions.GetDurability()
	local have, most, pct = 0,0,0
	local sOut
	for i = 1, 19 do
		local current, max = GetInventoryItemDurability(i)
		if current ~= nil then
			have = have + current
			most = most + max
		end
	end
	pct = math.floor((have/most) * 100)
	if pct >= 75 then
		sOut = "|cff00ff00"..pct
	elseif pct < 75 and pct > 50 then
		sOut = "|cfffbe550"..pct
	else
		sOut = "|cffff0000"..pct
	end
	return sOut
end

---------------------------
-- Clock Min function
---------------------------
function Glance.Functions.GetMin(min)
	if min < 10 then
		return "0"..min
	end
	return min
end

---------------------------
-- Clock Hour function
---------------------------
function Glance.Functions.GetHour(hour)
	if hour > 12 then
		hour = hour - 12
	end
	if hour < 10 then
		return "0"..hour
	end
	return hour
end

---------------------------
-- Clock DST function
---------------------------
function Glance.Functions.GetDST(hour)
	if hour < 12 then
		return "AM"
	else
		return "PM"
	end
end

---------------------------
-- lag format function
---------------------------
function Glance.Functions.formatLag()
	local lag = select(3, GetNetStats())
	local sLag
	if lag >= 350 then
		sLag = "|cffff0000"..lag
	elseif lag < 350 and lag > 200 then
		sLag = "|cfffbe550"..lag
	else
		sLag = "|cff00ff00"..lag
	end
	return sLag
end

---------------------------
-- fps format function
---------------------------
function Glance.Functions.formatFPS()
	local fps = math.floor(GetFramerate())
	local sfps
	if fps <= 8 then
		sfps = "|cffff0000"..fps
	elseif fps > 8 and fps < 15 then
		sfps = "|cfffbe550"..fps
	else
		sfps = "|cff00ff00"..fps
	end
	return sfps
end

---------------------------
-- color codes
---------------------------
function Glance.Functions.DecimalToHex(r,g,b)
    return string.format("|cff%02x%02x%02x", r*255, g*255, b*255)
end

---------------------------
-- text matching
---------------------------
function Glance.Functions.match(u,t,find)
	for i = 1, u do
		local text = string.lower(_G[t..i]:GetText())
		for word in string.gmatch(text, "%S+") do
			if strfind(string.lower(word), string.lower(find)) then return true end
		end
	end
	return false
end

---------------------------
-- send message
---------------------------
function Glance.Functions.sendMSG(text)
	print("|cffFF1E00Glance:|r "..tostring(text));
end


---------------------------
-- clear info
---------------------------
function Glance.Functions.resetInfo()
	wipe(Glance.Arrays.info)
	Glance.Arrays.info = {
		["disabled"]     = nil,
		["isTitle"]      = nil,
		["hasArrow"]     = nil,
		["notCheckable"] = nil,
		["checked"]      = nil,
		["text"]         = nil,
		["value"]        = nil
	}
end

---------------------------
-- get rep %
---------------------------
function Glance.Functions.getRep(bv,ev,tv)
	local pct
	if tv > 0 then
		pct = math.floor(((ev-bv)/(tv-bv))*100)
	else
		pct = -(math.floor(((ev-tv)/(tv-bv))*100))
	end
	return pct.."%"
end

---------------------------
-- armor repair
---------------------------
function Glance.Functions.repairArmor()
	if CanMerchantRepair()==1 and Glance_Options.autoRepair then
		local repairAllCost, canRepair = GetRepairAllCost();
		if repairAllCost>0 then
			if canRepair==1 then
				RepairAllItems();
				Glance.Functions.sendMSG("Your items have been repaired for "..GetCoinTextureString(repairAllCost,0))
			else
				Glance.Functions.sendMSG("You don't have enough money for repair!");
			end
		end
	end
	if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cFF69CCF0UDT: Glance.Functions.repairArmor()") end
end

---------------------------
-- get mount info
---------------------------
function Glance.Functions.mountInfo(id)
	GameTooltip_SetDefaultAnchor(Glance_Tooltip_Mount, UIParent)
	local creatureID, creatureName, creatureSpellID, icon, issummoned = GetCompanionInfo("MOUNT", id);
	local special, air, fast = false, false, false
	Glance_Tooltip_Mount:SetHyperlink("spell:"..creatureSpellID)
	air = Glance.Functions.airMounts()
	special = Glance.Functions.specialMounts()
	water = Glance.Functions.waterMounts()
	fast = special or Glance.Functions.fastMounts() 
	Glance_Tooltip_Mount:Hide();
	return creatureName, icon, issummoned, air, special, fast, water
end

---------------------------
-- search for flying mounts
---------------------------
function Glance.Functions.airMounts()
	local air = false
	for i=1, #Glance.Arrays.flightMounts do
		air = Glance.Functions.match(Glance_Tooltip_Mount:NumLines(),"Glance_Tooltip_MountTextLeft",Glance.Arrays.flightMounts[i])
		if air then return true end
	end
	return false
end

---------------------------
-- search for special mounts
---------------------------
function Glance.Functions.specialMounts()
	local special = false
	for i=1, #Glance.Arrays.specialMounts do
		special = Glance.Functions.match(Glance_Tooltip_Mount:NumLines(),"Glance_Tooltip_MountTextLeft",Glance.Arrays.specialMounts[i])
		if special then return true end
	end
	return false
end

---------------------------
-- search for fastmounts
---------------------------
function Glance.Functions.fastMounts()
	local fast = false
	for i=1, #Glance.Arrays.fastMounts do
		fast = Glance.Functions.match(Glance_Tooltip_Mount:NumLines(),"Glance_Tooltip_MountTextLeft",Glance.Arrays.fastMounts[i])
		if fast then return true end
	end
	return false
end

---------------------------
-- search for water mounts
---------------------------
function Glance.Functions.waterMounts()
	local water = false
	for i=1, #Glance.Arrays.waterMounts do
		water = Glance.Functions.match(Glance_Tooltip_Mount:NumLines(),"Glance_Tooltip_MountTextLeft",Glance.Arrays.waterMounts[i])
		if water then return true end
	end
	return false
end

---------------------------
-- store mounts in {}
---------------------------
function Glance.Functions.resetMountList()
	wipe(Glance.Arrays.mount)
	local mountListChanged = false
	for i=1,GetNumCompanions("MOUNT") do
		Glance.Arrays.mount[i] = { Glance.Functions.mountInfo(i) }
		if Glance_Options.mounts == nil then Glance_Options.mounts = {} end
		if Glance_Options.mounts[i] == nil then
			if Glance.Arrays.mount[i][6] then
				Glance_Options.mounts[i] = { Glance.Arrays.mount[i][1], "|cff9135B3" ,true }
			else
				Glance_Options.mounts[i] = { Glance.Arrays.mount[i][1], "|cff0070C0" ,true }
			end
			mountListChanged = true
		elseif Glance_Options.mounts[i][1] ~= Glance.Arrays.mount[i][1] then
			if Glance.Arrays.mount[i][6] then
				Glance_Options.mounts[i] = { Glance.Arrays.mount[i][1], "|cff9135B3" ,true }
			else
				Glance_Options.mounts[i] = { Glance.Arrays.mount[i][1], "|cff0070C0" ,true }
			end
			mountListChanged = true
		end
	end
	if mountListChanged then Glance.Functions.sendMSG("Your mount list has changed.  Type '/glance options' to reconfigure your preferences.") end
	if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cFFf40bcbUDT: Glance.Functions.resetMountList()") end
end

---------------------------
-- battleground status
---------------------------
function Glance.Functions.inBattleground()
	local pvpID, localizedName, isActive, canQueue, sec, canEnter = GetWorldPVPAreaInfo(1)
	if (isActive and GetZoneText()=="Wintergrasp") then
		return true;
	end
	pvpID, localizedName, isActive, canQueue, sec, canEnter = GetWorldPVPAreaInfo(2)
	if (isActive and GetZoneText()=="Tol Barad") then
		return true;
	end
	return false;
end

---------------------------
-- summon a random mount
---------------------------
function Glance.Functions.summonRandomMount()
	if IsOutdoors() then
		if IsSwimming() then
			if strfind(GetMapInfo(),"Vashj") then
				Glance.Functions.summonRandomWaterMount()
			elseif strfind(GetMapInfo(),"Thousand") then
				Glance.Functions.summonRandomWaterMount()
			else 
				Glance.Functions.summonRandomWaterMount()
			end
		else
			if (IsFlyableArea() and not Glance.Functions.inBattleground()) then
				Glance.Functions.summonRandomAirMount()
			else
				Glance.Functions.summonRandomLandMount()
			end
		end
	end
end

---------------------------
-- summon a random air mount
---------------------------
function Glance.Functions.summonRandomAirMount()
	local mountCount = 0
	local tmpmount = {}
	for i=1,#Glance.Arrays.mount do
		local creatureName, icon, issummoned, air, special, fast, water = unpack(Glance.Arrays.mount[i])
		local pvpID, localizedName, isActive, canQueue, sec, canEnter = GetWorldPVPAreaInfo(1)
		Glance.Arrays.mount[i][3] = false
		if (air or special) and Glance_Options.mounts[i][3] then
			mountCount = mountCount + 1
			tmpmount[mountCount] = i
		end
	end
	if #tmpmount > 0 then
		local rdm = tmpmount[random(1,#tmpmount)]
		Glance.Arrays.mount[rdm][3] = true
		CallCompanion("MOUNT",rdm)
		if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cffffff00 Calling air: "..rdm) end
	end
	wipe(tmpmount)
end

---------------------------
-- summon a random land mount
---------------------------
function Glance.Functions.summonRandomLandMount()
	local mountCount = 0
	local tmpmount = {}
	for i=1,#Glance.Arrays.mount do
		local creatureName, icon, issummoned, air, special, fast, water = unpack(Glance.Arrays.mount[i])
		Glance.Arrays.mount[i][3] = false
		if not (air or water) and Glance_Options.mounts[i][3] then
			mountCount = mountCount + 1
			tmpmount[mountCount] = i
		end
	end
	if #tmpmount > 0 then
		local rdm = tmpmount[random(1,#tmpmount)]
		Glance.Arrays.mount[rdm][3] = true
		CallCompanion("MOUNT",rdm)
		if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cffffff00 Calling land: "..rdm) end
	end
	wipe(tmpmount)
end

---------------------------
-- summon a random water mount
---------------------------
function Glance.Functions.summonRandomWaterMount()
	local mountCount = 0
	local tmpmount = {}
	for i=1,#Glance.Arrays.mount do
		local creatureName, icon, issummoned, air, special, fast, water = unpack(Glance.Arrays.mount[i])
		Glance.Arrays.mount[i][3] = false
		if water and Glance_Options.mounts[i][3] then
			mountCount = mountCount + 1
			tmpmount[mountCount] = i
		end
	end
	if #tmpmount > 0 then
		local rdm = tmpmount[random(1,#tmpmount)]
		Glance.Arrays.mount[rdm][3] = true
		CallCompanion("MOUNT",rdm)
		if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cffffff00 Calling water: "..rdm) end
	end
	wipe(tmpmount)
end

---------------------------
-- get pet info
---------------------------
function Glance.Functions.petInfo(id)
	local creatureID, creatureName, creatureSpellID, icon, issummoned = GetCompanionInfo("CRITTER", id);
	return creatureName, icon, issummoned
end

---------------------------
-- store pets in {}
---------------------------
function Glance.Functions.resetPetList()
	wipe(Glance.Arrays.pet)
	local petListChanged = false
	for i=1,GetNumCompanions("CRITTER") do
		Glance.Arrays.pet[i] = { Glance.Functions.petInfo(i) }
		if Glance_Options.pets == nil then Glance_Options.pets = {} end
		if Glance_Options.pets[i] == nil then
			Glance_Options.pets[i] = { Glance.Arrays.pet[i][1], true }
			petListChanged = true
		elseif Glance_Options.pets[i][1] ~= Glance.Arrays.pet[i][1] then
			Glance_Options.pets[i] = { Glance.Arrays.pet[i][1], true }
			petListChanged = true
		end
	end
	if petListChanged then Glance.Functions.sendMSG("Your pet list has changed.  Type '/glance options' to reconfigure your preferences.") end
	if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cFFf40bcbUDT: Glance.Functions.resetPetList()") end
end