--------------------------------------------------------------------
-- Menus
--------------------------------------------------------------------


---------------------------
-- rep dropdown
---------------------------
Glance.Menus.Rep = CreateFrame("Frame", "Glance.Menus.Rep")
Glance.Menus.Rep.displayMode = "MENU"
Glance.Menus.Rep.initialize = function(self, level)
	ExpandAllFactionHeaders()
	local hName = " "
	level = level or 1
	if (level == 1) then
		Glance.Functions.resetInfo()
		for i=1,GetNumFactions() do
			local name,_,_,_,_,_,_,_,isHeader,_,_,_,_ = GetFactionInfo(i)
			if isHeader then
				Glance.Arrays.info.text = "|cffffd700"..name
				Glance.Arrays.info.value = name
				Glance.Arrays.info.hasArrow = true
				Glance.Arrays.info.notCheckable = true
				UIDropDownMenu_AddButton(Glance.Arrays.info, level)
			end
		end
	end
	if (level == 2) then
		Glance.Functions.resetInfo()
		for i=1,GetNumFactions() do
			local name,_,_,bottomValue,topValue,earnedValue,_,_,isHeader,_,_,isWatched,_ = GetFactionInfo(i)
			if isHeader then hName = name end
			if hName == UIDROPDOWNMENU_MENU_VALUE and not isHeader then
				Glance.Arrays.info.text = Glance.Arrays.colors[Glance.Arrays.rep[""..topValue]]..Glance.Arrays.rep[""..topValue].." ("..Glance.Functions.getRep(bottomValue,earnedValue,topValue)..") |r"..name
				Glance.Arrays.info.value = hName
				Glance.Arrays.info.hasArrow = false
				if isWatched then
					Glance.Arrays.info.checked = true
					Glance.Arrays.info.func = function() SetWatchedFactionIndex(0); Glance.Functions.updateRep() end;
				else
					Glance.Arrays.info.checked = false
					Glance.Arrays.info.func = function() SetWatchedFactionIndex(i) end;
				end
				UIDropDownMenu_AddButton(Glance.Arrays.info, level)
			end
		end
	end
	if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cffffff00MEN: Rep Menu") end
end

---------------------------
-- toggle rep menu
---------------------------
function Glance.Functions.menuToggleRep(self, button, ...)
	ToggleDropDownMenu(1, nil, Glance.Menus.Rep, self:GetName(), 0, 0)
end

---------------------------
-- professions dropdown
---------------------------
Glance.Menus.Profession = CreateFrame("Frame", "Glance.Menus.Profession")
Glance.Menus.Profession.displayMode = "MENU"
Glance.Menus.Profession.initialize = function(self, level)
		if not level then return end
		Glance.Functions.resetInfo()
		if level == 1 then
			local prof1, prof2, archaeology, fishing, cooking, firstAid = GetProfessions();
			local Professions = {
				[1] = prof1,
				[2] = prof2,
				[3] = archaeology,
				[4] = fishing,
				[5] = cooking,
				[6] = firstAid
			}
			for i=1,6 do
				if Professions[i] ~= nil then
					local name, icon, skillLevel, maxSkillLevel,_,_,_,_ = GetProfessionInfo(Professions[i])
					Glance.Arrays.info.text = name
					Glance.Arrays.info.icon = icon
					if Glance_Options.Profession == Professions[i] then
						Glance.Arrays.info.checked = true
					else
						Glance.Arrays.info.checked = false
					end
					Glance.Arrays.info.func = function() Glance_Options.Profession = Professions[i] Glance.Functions.updateProfessions() end;
					UIDropDownMenu_AddButton(Glance.Arrays.info, level)
				end
			end
		end
	if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cffffff00MEN: Professions Menu") end
end

---------------------------
-- toggle professions menu
---------------------------
function Glance.Functions.menuToggleProfession(self, button, ...)
	ToggleDropDownMenu(1, nil, Glance.Menus.Profession, self:GetName(), 0, 0)
end

---------------------------
-- mount dropdown
---------------------------
CreateFrame("GameTooltip","Glance_Tooltip_Mount",UIParent,"GameTooltipTemplate")
Glance.Menus.Mounts = CreateFrame("Frame", "Glance.Menus.Mounts")
Glance.Menus.Mounts.displayMode = "MENU"
Glance.Menus.Mounts.initialize = function(self, level)
		if not level then return end
		Glance.Functions.resetInfo()
		Glance.Functions.resetMountList()
		level = level or 1
		if (level == 1) then
				Glance.Arrays.info.text = "|cffffd700Flying"
				Glance.Arrays.info.value = "Flying"
				Glance.Arrays.info.hasArrow = true
				Glance.Arrays.info.notCheckable = true
				UIDropDownMenu_AddButton(Glance.Arrays.info, level)
				Glance.Arrays.info.text = "|cffffd700Riding"
				Glance.Arrays.info.value = "Riding"
				Glance.Arrays.info.hasArrow = true
				Glance.Arrays.info.notCheckable = true
				UIDropDownMenu_AddButton(Glance.Arrays.info, level)
				Glance.Arrays.info.text = "|cffffd700Swimming"
				Glance.Arrays.info.value = "Swimming"
				Glance.Arrays.info.hasArrow = true
				Glance.Arrays.info.notCheckable = true
				UIDropDownMenu_AddButton(Glance.Arrays.info, level)
		end
		if (level == 2) then
			if (UIDROPDOWNMENU_MENU_VALUE == "Flying") then
				for i=1,#Glance.Arrays.mount do
					local creatureName, icon, issummoned, air, special, fast, water = unpack(Glance.Arrays.mount[i])
					if (air or special) and Glance_Options.mounts[i][3] then
						Glance.Arrays.info.text = "|cffffffff"..creatureName
						Glance.Arrays.info.icon = icon
						if issummoned then
							Glance.Arrays.info.checked = true
							Glance.Arrays.info.func = function() DismissCompanion("MOUNT") end;
						else
							Glance.Arrays.info.checked = false
							Glance.Arrays.info.func = function() CallCompanion("MOUNT",i) end;
						end
						Glance.Arrays.info.hasArrow = false
						UIDropDownMenu_AddButton(Glance.Arrays.info, level)
					end
				end
			end
			if (UIDROPDOWNMENU_MENU_VALUE == "Riding") then
				for i=1,#Glance.Arrays.mount do
					local creatureName, icon, issummoned, air, special, fast, water = unpack(Glance.Arrays.mount[i])
					if (not (air or water) or special) and Glance_Options.mounts[i][3] then
						Glance.Arrays.info.text = "|cffffffff"..creatureName
						Glance.Arrays.info.icon = icon
						if issummoned then
							Glance.Arrays.info.checked = true
							Glance.Arrays.info.func = function() DismissCompanion("MOUNT") end;
						else
							Glance.Arrays.info.checked = false
							Glance.Arrays.info.func = function() CallCompanion("MOUNT",i) end;
						end
						Glance.Arrays.info.hasArrow = false
						UIDropDownMenu_AddButton(Glance.Arrays.info, level)
					end
				end
			end
			if (UIDROPDOWNMENU_MENU_VALUE == "Swimming") then
				for i=1,#Glance.Arrays.mount do
					local creatureName, icon, issummoned, air, special, fast, water = unpack(Glance.Arrays.mount[i])
					if water and Glance_Options.mounts[i][3] then
						Glance.Arrays.info.text = "|cffffffff"..creatureName
						Glance.Arrays.info.icon = icon
						if issummoned then
							Glance.Arrays.info.checked = true
							Glance.Arrays.info.func = function() DismissCompanion("MOUNT") end;
						else
							Glance.Arrays.info.checked = false
							Glance.Arrays.info.func = function() CallCompanion("MOUNT",i) end;
						end
						Glance.Arrays.info.hasArrow = false
						UIDropDownMenu_AddButton(Glance.Arrays.info, level)
					end
				end
			end
		end
	if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cffffff00MEN: Mount Menu") end
	Glance_Tooltip_Mount:Hide();
end

---------------------------
-- toggle mount menu
---------------------------
function Glance.Functions.menuToggleMount(self, button, ...)
	ToggleDropDownMenu(1, nil, Glance.Menus.Mounts, self:GetName(), 0, 0)
end

---------------------------
-- pet dropdown
---------------------------
CreateFrame("GameTooltip","Glance_Tooltip_Pet",UIParent,"GameTooltipTemplate")
Glance.Menus.Pets = CreateFrame("Frame", "Glance.Menus.Pets")
Glance.Menus.Pets.displayMode = "MENU"
Glance.Menus.Pets.initialize = function(self, level)
		if not level then return end
		Glance.Functions.resetInfo()
		Glance.Functions.resetPetList()
		level = level or 1
		if (level == 1) then
			for i=1,#Glance.Arrays.pet do
				if Glance_Options.pets[i][2] then
					local creatureName, icon, issummoned = unpack(Glance.Arrays.pet[i])
					Glance.Arrays.info.text = creatureName
					Glance.Arrays.info.icon = icon
					if issummoned then
						Glance.Arrays.info.checked = true
						Glance.Arrays.info.func = function() DismissCompanion("CRITTER") end;
					else
						Glance.Arrays.info.checked = false
						Glance.Arrays.info.func = function() CallCompanion("CRITTER",i) end;
					end
					Glance.Arrays.info.hasArrow = false
					UIDropDownMenu_AddButton(Glance.Arrays.info, level)
				end
			end
		end
	if Glance.Variables.Debug then Glance.Functions.sendMSG("DBG: |cffffff00MEN: Pet Menu") end
	Glance_Tooltip_Pet:Hide();
end

---------------------------
-- toggle Pet menu
---------------------------
function Glance.Functions.menuTogglePet(self, button, ...)
	ToggleDropDownMenu(1, nil, Glance.Menus.Pets, self:GetName(), 0, 0)
end